@@ -10,7 +10,7 @@
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
-# limitations under the License. 
+# limitations under the License.
 
 import base64
 import os
@@ -18,18 +18,19 @@ import requests
 import liboidcagent as agent
 _DEFAULT_TIMEOUT = 60
 
-""" Generic http request """
-def make_request(c , path, method, **kwargs):
 
-    headers = get_headers(c)  
+def make_request(c, path, method, **kwargs):
+    """ Generic http request """
 
-    if "timeout" in kwargs.keys() and kwargs["timeout"]: 
+    headers = get_headers(c)
+
+    if "timeout" in kwargs.keys() and kwargs["timeout"]:
         timeout = kwargs["timeout"]
-    else: 
+    else:
         timeout = _DEFAULT_TIMEOUT
 
     url = c.endpoint+path
-    
+
     if method in ["post", "put"]:
         if "token" in kwargs.keys() and kwargs["token"]: 
             headers = get_headers_with_token(kwargs["token"])
@@ -40,37 +41,42 @@ def make_request(c , path, method, **kwargs):
 
     if "handle" in kwargs.keys() and kwargs["handle"] == False:
         return result
-    
+
     result.raise_for_status()
     return result
 
-""" Function to generate headers with basic authentication or OIDC """
+
 def get_headers(c):
+    """ Function to generate headers with basic authentication or OIDC """
     if c._AUTH_TYPE == "basicauth":
-        usr_pass_as_bytes = bytes(c.user+":"+c.password,"utf-8")
+        usr_pass_as_bytes = bytes(c.user + ":" + c.password, "utf-8")
         usr_pass_base_64 = base64.b64encode(usr_pass_as_bytes).decode("utf-8")
-        return {"Authorization": "Basic "+ usr_pass_base_64}
+        return {"Authorization": "Basic " + usr_pass_base_64}
     if c._AUTH_TYPE == "oidc-agent":
         token = agent.get_access_token(c.shortname)
         return get_headers_with_token(token)
     if c._AUTH_TYPE == "oidc":
         return get_headers_with_token(c.oidc_token)
 
-""" Function to generate headers with token auth """
+
 def get_headers_with_token(token):
-    return {"Authorization": "Bearer "+ str(token)}
+    """ Function to generate headers with token auth """
+    return {"Authorization": "Bearer " + str(token)}
+
 
 def write_text_file(content, file_path):
     with open(file_path, 'w') as f:
         f.write(content)
 
+
 def isBase64(st):
     try:
         base64.b64decode(st)
         return True
-    except:
+    except Exception:
         return False
 
+
 def decode_b64(b64_str, file_out):
     file_extension = os.path.splitext(file_out)[1]
     try:
@@ -80,7 +86,7 @@ def decode_b64(b64_str, file_out):
             decode = 'w'
             decoded_data = decoded_data.decode("utf-8")
         else:
-            decode = 'wb' 
+            decode = 'wb'
 
         with open(file_out, decode) as f:
             f.write(decoded_data)
@@ -90,6 +96,7 @@ def decode_b64(b64_str, file_out):
     except OSError:
         print('Error decoding output: Failed to write decoded data to file.')   
 
+
 def encode_input(data):
     if os.path.isfile(data):
         try:
@@ -103,12 +110,11 @@ def encode_input(data):
         message_bytes = data.encode('ascii')
         return base64.b64encode(message_bytes)
 
+
 def decode_output(output, file_path):
-    if(isBase64(output)):
+    if isBase64(output):
         decode_b64(output, file_path)
         return
-    if(isinstance(output,str)):
-        write_text_file(output,file_path)
+    if isinstance(output, str):
+        write_text_file(output, file_path)
         return
-
- 
